@@ -3,17 +3,26 @@ from python_framework import Service, ServiceMethod
 
 import QueueDto
 import QueueModel
+from util import AuditoryUtil
 
 
 @Service()
 class QueueModelService:
 
+    @ServiceMethod()
+    def findAllByOrigin(self):
+        modelList = self.repository.queueModel.findAllByOriginKey(AuditoryUtil.getApiKeyIdentity(service=self))
+        return self.mapper.queueModel.fromModelListToResponseDtoList(
+            modelList
+        )
+
+
     @ServiceMethod(requestClass=[QueueDto.QueueRequestDto])
     def createOrUpdate(self, dto):
         self.validator.queueModel.validateRequestDto(dto)
         model = self.findOptionalModelByKey(dto.key)
         if ObjectHelper.isNone(model):
-            model = self.mapper.queueModel.fromRequestDtoToModel(dto)
+            model = self.mapper.queueModel.fromRequestDtoToModel(dto, AuditoryUtil.getApiKeyIdentity(service=self))
         else:
             self.mapper.queueModel.overrideModel(model, dto)
         return self.mapper.queueModel.fromModelToResponseDto(self.persist(model))
